# Table of Contents

- [cost-management](<./cost-management.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Cost Management](<./Cost-Management.md>)
  - [Overview](<./Cost-Management/Overview.md>)
  - [Project Cost](<./Cost-Management/Project-Cost.md>)
  - [Application Cost](<./Cost-Management/Application-Cost.md>)
  - [Infrastructure Cost](<./Cost-Management/Infrastructure-Cost.md>)
  - [Collect and Update Cost Data](<./Cost-Management/Collect-and-Update-Cost-Data.md>)
  - [Advanced Cost Management with Customized Configurations](<./Cost-Management/Advanced-Cost-Management-with-Customized-Configurations.md>)
  - [Additional Information](<./Cost-Management/Additional-Information.md>)
  - [Was this page helpful?](<./Cost-Management/Was-this-page-helpful.md>)
